@@ -24,6 +24,14 @@ from ChromeController.Generator.Generated import ChromeRemoteDebugInterface as C
 
 DEFAULT_TIMEOUT_SECS = 10
 
+class RemoteObject():
+	def __init__(self, object_meta):
+		self.object_meta = object_meta
+
+		# TODO: Allow retreiving/interacting with these.
+	def __repr__(self):
+		return "<(Unimplemented) RemoteObject for JS object: '%s'>" % (self.object_meta, )
+
 class ChromeRemoteDebugInterface(ChromeRemoteDebugInterface_base):
 	'''
 	Remote control class for Chromium.
@@ -195,8 +203,17 @@ class ChromeRemoteDebugInterface(ChromeRemoteDebugInterface_base):
 		return ret
 
 	def __decode_serialized_value(self, value):
-		assert 'type' in value
-		assert 'value' in value
+		assert 'type' in value,  "Missing 'type' key from value: '%s'" % (value, )
+
+		if 'get' in value and 'set' in value:
+			# self.log.warning("Unserializable remote script object")
+			return RemoteObject(value['objectId'])
+
+		if value['type'] == 'object' and 'objectId' in value:
+			# self.log.warning("Unserializable remote script object")
+			return RemoteObject(value['objectId'])
+
+		assert 'value' in value, "Missing 'value' key from value: '%s'" % (value, )
 
 		if value['type'] == 'number':
 			return float(value['value'])
